
/****************************************************************************
**********        MFR - Management and Financial Reporting        ***********
*****************************************************************************

Initial script which creates the objects (views and stored procedures)
used in the Management and Financial Reporting Blueprint

Version: 1.0.1
Created by: Rickard Rygin, Cognos Innovation Center
Date: 22.08.04
Last Changed: 05.05.2006, Rickard Rygin

*****************************************************************************
******* VXOLAPSECURITY
****************************************************************************/

BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VXOLAPSECURITY';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VXOLAPSECURITY 
AS 
SELECT DISTINCT
		 A.CONTROLLERUSER,
		 '' AS NTUSER,
		 A.CAMUSER,
		 B.KONFTXT AS USERNAME
FROM  XCAMUSER A,
	 XKONFIG B 
WHERE	 B.TYP1  = 'U'
 AND	B.TYP2  = 'NAMN'
 AND	A.CONTROLLERUSER  = B.ANVID

/

/****************************************************************************
******* VACCOUNTS
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VACCOUNTS';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VACCOUNTS 
AS 
SELECT DISTINCT
		 A.CUBEID AS TEMPLATE,
		 
			CASE
				 WHEN INSTR(SUBSTR(A.PARENT, 2, LENGTH(RTRIM(A.PARENT)) - 1), ':', 1)  > 0 THEN SUBSTR(SUBSTR(A.PARENT, 2, LENGTH(RTRIM(A.PARENT)) - 1), 2, INSTR(SUBSTR(A.PARENT, 2, LENGTH(RTRIM(A.PARENT)) - 1), ':', 1) - 1)
				 ELSE LTRIM(RTRIM(SUBSTR(A.PARENT, 2, LENGTH(RTRIM(A.PARENT)) - 1)))
			 END AS FORM,
		 
(
SELECT DISTINCT RTRIM(C.NAME)
FROM  XOCUBEACC C 
WHERE	 LTRIM(RTRIM(C.JOINCOL))  = LTRIM(RTRIM(A.PARENT))

)
 AS FORM_NAME,
		 LTRIM(RTRIM(A.JOINCOL)) AS ACCOUNT,
		 RTRIM(A.NAME) AS ACCOUNT_NAME,
		 NVL(B.SUMRAD, 'F') AS SUMMATION_ACCOUNT,
		 A.SORTORD AS SORTORDER,
		 B.NIV1 AS LEVEL1,
		 B.NIV2 AS LEVEL2,
		 B.NIV3 AS LEVEL3,
		 B.NIV4 AS LEVEL4,
		 b.RADTYP AS ACCOUNT_TYPE
FROM  XOCUBEACC A,
	 XKONTO B 
WHERE	 A.JOINCOL  = B.KONTO
 AND	(SUBSTR(A.PARENT, 0, 1)  = '#'
 AND	SUBSTR(A.JOINCOL, 0, 1)  <> '#')

/

/****************************************************************************
******* VACCOUNTS_FLAT
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VACCOUNTS_FLAT';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VACCOUNTS_FLAT 
AS 
SELECT DISTINCT
		 A.CUBEID AS TEMPLATE,
		 A.JOINCOL AS ACCOUNT,
		 RTRIM(A.NAME) AS ACCOUNT_NAME,
		 NVL(B.SUMRAD, 'F') AS SUMMATION_ACCOUNT,
		 B.SORTORD AS SORTORDER,
		 B.NIV1 AS LEVEL1,
		 B.NIV2 AS LEVEL2,
		 B.NIV3 AS LEVEL3,
		 B.NIV4 AS LEVEL4,
		 b.RADTYP AS ACCOUNT_TYPE
FROM  XOCUBEACC A,
	 XKONTO B 
WHERE	 A.JOINCOL  = B.KONTO

/

/****************************************************************************
******* VACCOUNTS_LEVEL'
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VACCOUNTS_LEVEL';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VACCOUNTS_LEVEL 
AS 
SELECT DISTINCT
		 A.CUBEID AS TEMPLATE,
		 
			CASE
				 WHEN INSTR(SUBSTR(A.PARENT, 2, LENGTH(RTRIM(A.PARENT)) - 1), ':', 1)  > 0 THEN SUBSTR(SUBSTR(A.PARENT, 1, LENGTH(RTRIM(A.PARENT)) - 1), 1, INSTR(SUBSTR(A.PARENT, 1, LENGTH(RTRIM(A.PARENT)) - 1), ':', 1) - 1)
				 ELSE SUBSTR(A.PARENT, 1, LENGTH(RTRIM(A.PARENT)))
			 END AS SUM_ACCOUNT,
		 
(
SELECT DISTINCT RTRIM(C.NAME)
FROM  XOCUBEACC C 
WHERE	 C.JOINCOL  = 
	CASE
		 WHEN INSTR(SUBSTR(A.PARENT, 2, LENGTH(RTRIM(A.PARENT)) - 1), ':', 1)  > 0 THEN SUBSTR(SUBSTR(A.PARENT, 1, LENGTH(RTRIM(A.PARENT)) - 1), 1, INSTR(SUBSTR(A.PARENT, 1, LENGTH(RTRIM(A.PARENT)) - 1), ':', 1) - 1)
		 ELSE SUBSTR(A.PARENT, 1, LENGTH(RTRIM(A.PARENT)))
	 END

)
 AS SUM_ACC_NAME,
		 A.JOINCOL AS ACCOUNT,
		 A.NAME AS ACCOUNT_NAME,
		 NVL(B.SUMRAD, 'F') AS SUMMATION_ACCOUNT,
		 A.SORTORD AS SORTORDER,
		 B.NIV1 AS LEVEL1,
		 B.NIV2 AS LEVEL2,
		 B.NIV3 AS LEVEL3,
		 B.NIV4 AS LEVEL4,
		 b.RADTYP AS ACCOUNT_TYPE
FROM  XOCUBEACC A,
	 XKONTO B 
WHERE	 A.JOINCOL  = B.KONTO
 AND	(SUBSTR(A.PARENT, 0, 1)  <> '#'
 AND	SUBSTR(A.JOINCOL, 0, 1)  <> '#'
 AND	
	CASE
		 WHEN INSTR(SUBSTR(A.PARENT, 2, LENGTH(RTRIM(A.PARENT)) - 1), ':', 1)  > 0 THEN SUBSTR(SUBSTR(A.PARENT, 1, LENGTH(RTRIM(A.PARENT)) - 1), 1, INSTR(SUBSTR(A.PARENT, 1, LENGTH(RTRIM(A.PARENT)) - 1), ':', 1) - 1)
		 ELSE SUBSTR(A.PARENT, 1, LENGTH(RTRIM(A.PARENT)))
	 END  <> A.JOINCOL)

/

/****************************************************************************
******* VACTUALITIES
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VACTUALITIES';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VACTUALITIES 
AS 
SELECT DISTINCT
		 CUBEID AS TEMPLATE,
		 ACT AS ACTUALITY,
		 RTRIM(NAME) AS ACTUALITY_NAME
FROM  XOCUBEACT 

/

/****************************************************************************
******* VCLOSINGVERSIONS
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VCLOSINGVERSIONS';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VCLOSINGVERSIONS 
AS 
SELECT DISTINCT
		 CUBEID AS TEMPLATE,
		 PARENT AS CLOSING_VERSION,
		 RTRIM(PARENTNAME) AS CLOSING_VERSION_NAME,
		 CHILD AS JOURNALTYPE,
		 RTRIM(CHILDNAME) AS JOURNALTYPE_NAME
FROM  XOCUBECLOSVER 

/

/****************************************************************************
******* VCLOSVERSECURITY
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VCLOSVERSECURITY';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VCLOSVERSECURITY 
AS 
SELECT DISTINCT
		 B.NTUSER AS OSUSER,
		 B.CONTROLLERUSER AS CONTROLLERUSER,
		 B.CAMUSER,
		 B.USERNAME,
		 A.TOMEDLEM AS CLOSING_VERSION
FROM  XNYST A,
	 VXOLAPSECURITY B 
WHERE	 A.FRMEDLEM  = B.CONTROLLERUSER
 AND	A.FRGRPTYP  = 'UV'
UNION
 SELECT
		 B.NTUSER AS OSUSER,
		 B.CONTROLLERUSER AS CONTROLLERUSER,
		 B.CAMUSER,
		 B.USERNAME,
		 A.ID AS CLOSING_VERSION
FROM  XID A,
	 VXOLAPSECURITY B 
WHERE	 B.CONTROLLERUSER  NOT IN
	(
 	SELECT FRMEDLEM
	FROM  XNYST 
	WHERE	 FRGRPTYP  = 'UV'
	)
 

/

/****************************************************************************
******* VCOMPANIES
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VCOMPANIES';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VCOMPANIES
AS 
SELECT A.CUBEID AS TEMPLATE, 
CASE  
 WHEN A.PARENT = A.CHILD THEN '' 
        ELSE  
   CASE  
     WHEN LENGTH(A.PARENT) > 0 AND INSTR(A.PARENT,':', 1, 1) > 0  
     THEN SUBSTR(A.PARENT, 1, INSTR(A.PARENT,':', 1, 1) - 1) 
   ELSE 
     A.PARENT 
   END 
END AS GROUP_ID, 
CASE  
 WHEN A.PARENT = A.CHILD THEN TO_NCHAR('') 
     ELSE  
 NVL((SELECT C.NAME FROM XOCUBECOMP C  
 WHERE C.CHILD=A.PARENT  
 AND C.CUBEID=A.CUBEID),'') 
END AS GROUP_NAME, 
A.JOINCOL AS COMPANY,  
A.NAME AS COMPANY_NAME,  
A.SORTORD AS SORTORDER,  
A.VKODLC AS LOCAL_CURRENCY, 
NVL((SELECT B.VKODLC  
FROM XOCUBECOMP B  
WHERE B.CHILD=A.PARENT AND B.CUBEID=A.CUBEID),'') AS GROUP_CURRENCY,
NVL((SELECT C.BOLTYP
FROM XBO C
WHERE A.JOINCOL = C.BOL),'') AS COMPANY_TYPE
FROM XOCUBECOMP A
/


/****************************************************************************
******* VCOMPANIES_FLAT
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VCOMPANIES_FLAT';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VCOMPANIES_FLAT 
AS 
SELECT DISTINCT
		 A.CUBEID AS TEMPLATE,
		 A.JOINCOL AS COMPANY,
		 RTRIM(A.NAME) AS COMPANY_NAME,
		 A.SORTORD AS SORTORDER,
		 A.VKODLC AS LOCAL_CURRENCY,
		 B.BOLTYP AS COMPANY_TYPE
FROM  XOCUBECOMP A,
	 XBO B 
WHERE	 A.JOINCOL  = B.BOL

/

/****************************************************************************
******* VCOMPANYSECURITY
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VCOMPANYSECURITY';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VCOMPANYSECURITY 
AS 
SELECT DISTINCT
		 B.NTUSER AS OSUSER,
		 B.CONTROLLERUSER AS CONTROLLERUSER,
		 B.CAMUSER,
		 B.USERNAME,
		 A.TOMEDLEM AS COMPANY
FROM  XNYST A,
	 VXOLAPSECURITY B 
WHERE	 A.FRMEDLEM  = B.CONTROLLERUSER
 AND	A.FRGRPTYP  = 'UC'
UNION
 SELECT
		 B.NTUSER AS OSUSER,
		 B.CONTROLLERUSER AS CONTROLLERUSER,
		 B.CAMUSER,
		 B.USERNAME,
		 A.BOL AS COMPANY
FROM  XBO A,
	 VXOLAPSECURITY B 
WHERE	 B.CONTROLLERUSER  NOT IN
	(
 	SELECT FRMEDLEM
	FROM  XNYST 
	WHERE	 FRGRPTYP  = 'UC'
	)
 

/

/****************************************************************************
******* VCONTRIBUTIONVERSIONS
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VCONTRIBUTIONVERSIONS';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VCONTRIBUTIONVERSIONS 
AS 
SELECT DISTINCT
		 CUBEID AS TEMPLATE,
		 PARENT AS CONTRIBUTION_VERSION,
		 RTRIM(PARENTNAME) AS CONTRIBUTION_VERSION_NAME,
		 CHILD AS AUTOMATIC_JOURNALTYPE,
		 RTRIM(CHILDNAME) AS AUTOMATIC_JOURNALTYPE_NAME
FROM  XOCUBECONTRIB 

/

/****************************************************************************
******* VCOUNTERCOMPANIES
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VCOUNTERCOMPANIES';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VCOUNTERCOMPANIES 
AS 
SELECT DISTINCT
		 A.CUBEID AS TEMPLATE,
		 A.JOINCOL AS COMPANY,
		 RTRIM(A.NAME) AS COMPANY_NAME,
		 A.SORTORD AS SORTORDER
FROM  XOCUBECOMP A 

/

/****************************************************************************
******* VCOUNTERDIMENSION
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VCOUNTERDIMENSION';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VCOUNTERDIMENSION 
AS 
SELECT DISTINCT
		 A.CUBEID AS TEMPLATE,
		 A.CHILD AS DIM1,
		 RTRIM(A.NAME) AS DIM1_NAME
FROM  XOCUBEDIM1 A,
	 XKOD B 
WHERE	 A.CHILD  = B.KOD
 AND	B.TYP  = '1'

/

/****************************************************************************
******* VCURRENCIES
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VCURRENCIES';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VCURRENCIES 
AS 
SELECT DISTINCT
		 CUBEID AS TEMPLATE,
		 VKOD AS CURRENCY,
		 SORTORD AS SORTORDER
FROM  XOCUBECURR 

/

/****************************************************************************
******* VDIM1
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VDIM1';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VDIM1 
AS 
SELECT DISTINCT
		 A.CUBEID AS TEMPLATE,
		 A.PARENT AS PARENT,
		 
(
SELECT RTRIM(NAME)
FROM  XOCUBEDIM1 C 
WHERE	 C.CHILD  = A.PARENT
 AND	C.CUBEID  = A.CUBEID

)
 AS PARENT_NAME,
		 LTRIM(RTRIM(A.CHILD)) AS DIM1,
		 RTRIM(A.NAME) AS DIM1_NAME,
		 B.NIV AS DIM_LEVEL
FROM  XOCUBEDIM1 A,
	 XKOD B 
WHERE	 A.CHILD  = B.KOD
 AND	B.TYP  = '1'

/

/****************************************************************************
******* VDIM1SECURITY
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VDIM1SECURITY';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VDIM1SECURITY 
AS 
SELECT DISTINCT
		 B.NTUSER AS OSUSER,
		 B.CONTROLLERUSER AS CONTROLLERUSER,
		 B.CAMUSER,
		 B.USERNAME,
		 A.TOMEDLEM AS DIM1
FROM  XNYST A,
	 VXOLAPSECURITY B 
WHERE	 A.FRMEDLEM  = B.CONTROLLERUSER
 AND	A.FRGRPTYP  = 'U1'
UNION
 SELECT
		 B.NTUSER AS OSUSER,
		 B.CONTROLLERUSER AS CONTROLLERUSER,
		 B.CAMUSER,
		 B.USERNAME,
		 LTRIM(RTRIM(A.KOD)) AS DIM1
FROM  XKOD A,
	 VXOLAPSECURITY B 
WHERE	 B.CONTROLLERUSER  NOT IN
	(
 	SELECT FRMEDLEM
	FROM  XNYST 
	WHERE	 FRGRPTYP  = 'U1'
	)
 AND	A.TYP  = '1'
UNION ALL
 SELECT DISTINCT
		 B.NTUSER AS OSUSER,
		 B.CONTROLLERUSER AS CONTROLLERUSER,
		 B.CAMUSER,
		 B.USERNAME,
		 '' AS DIM1
FROM  XNYST A,
	 VXOLAPSECURITY B 
WHERE	 A.FRMEDLEM  = B.CONTROLLERUSER
 AND	A.FRGRPTYP  = 'U1'
 
 

/

/****************************************************************************
******* VDIM2
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VDIM2';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VDIM2 
AS 
SELECT DISTINCT
		 A.CUBEID AS TEMPLATE,
		 A.PARENT AS PARENT,
		 
(
SELECT RTRIM(NAME)
FROM  XOCUBEDIM2 C 
WHERE	 C.CHILD  = A.PARENT
 AND	C.CUBEID  = A.CUBEID

)
 AS PARENT_NAME,
		 LTRIM(RTRIM(A.CHILD)) AS DIM2,
		 RTRIM(A.NAME) AS DIM2_NAME,
		 B.NIV AS DIM_LEVEL
FROM  XOCUBEDIM2 A,
	 XKOD B 
WHERE	 A.CHILD  = B.KOD
 AND	B.TYP  = '2'

/

/****************************************************************************
******* VDIM2SECURITY
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VDIM2SECURITY';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VDIM2SECURITY 
AS 
SELECT DISTINCT
		 B.NTUSER AS OSUSER,
		 B.CONTROLLERUSER AS CONTROLLERUSER,
		 B.CAMUSER,
		 B.USERNAME,
		 A.TOMEDLEM AS DIM2
FROM  XNYST A,
	 VXOLAPSECURITY B 
WHERE	 A.FRMEDLEM  = B.CONTROLLERUSER
 AND	A.FRGRPTYP  = 'U2'
UNION
 SELECT
		 B.NTUSER AS OSUSER,
		 B.CONTROLLERUSER AS CONTROLLERUSER,
		 B.CAMUSER,
		 B.USERNAME,
		 LTRIM(RTRIM(A.KOD)) AS DIM2
FROM  XKOD A,
	 VXOLAPSECURITY B 
WHERE	 B.CONTROLLERUSER  NOT IN
	(
 	SELECT FRMEDLEM
	FROM  XNYST 
	WHERE	 FRGRPTYP  = 'U2'
	)
 AND	A.TYP  = '2'
UNION ALL
 SELECT DISTINCT
		 B.NTUSER AS OSUSER,
		 B.CONTROLLERUSER AS CONTROLLERUSER,
		 B.CAMUSER,
		 B.USERNAME,
		 '' AS DIM2
FROM  XNYST A,
	 VXOLAPSECURITY B 
WHERE	 A.FRMEDLEM  = B.CONTROLLERUSER
 AND	A.FRGRPTYP  = 'U2'
 
 

/

/****************************************************************************
******* VDIM3
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VDIM3';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VDIM3 
AS 
SELECT DISTINCT
		 A.CUBEID AS TEMPLATE,
		 A.PARENT AS PARENT,
		 
(
SELECT RTRIM(NAME)
FROM  XOCUBEDIM3 C 
WHERE	 C.CHILD  = A.PARENT
 AND	C.CUBEID  = A.CUBEID

)
 AS PARENT_NAME,
		 LTRIM(RTRIM(A.CHILD)) AS DIM3,
		 RTRIM(A.NAME) AS DIM3_NAME,
		 B.NIV AS DIM_LEVEL
FROM  XOCUBEDIM3 A,
	 XKOD B 
WHERE	 A.CHILD  = B.KOD
 AND	B.TYP  = '3'

/

/****************************************************************************
******* VDIM3SECURITY
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VDIM3SECURITY';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VDIM3SECURITY 
AS 
SELECT DISTINCT
		 B.NTUSER AS OSUSER,
		 B.CONTROLLERUSER AS CONTROLLERUSER,
		 B.CAMUSER,
		 B.USERNAME,
		 A.TOMEDLEM AS DIM3
FROM  XNYST A,
	 VXOLAPSECURITY B 
WHERE	 A.FRMEDLEM  = B.CONTROLLERUSER
 AND	A.FRGRPTYP  = 'U3'
UNION
 SELECT
		 B.NTUSER AS OSUSER,
		 B.CONTROLLERUSER AS CONTROLLERUSER,
		 B.CAMUSER,
		 B.USERNAME,
		 LTRIM(RTRIM(A.KOD)) AS DIM3
FROM  XKOD A,
	 VXOLAPSECURITY B 
WHERE	 B.CONTROLLERUSER  NOT IN
	(
 	SELECT FRMEDLEM
	FROM  XNYST 
	WHERE	 FRGRPTYP  = 'U3'
	)
 AND	A.TYP  = '3'
UNION ALL
 SELECT DISTINCT
		 B.NTUSER AS OSUSER,
		 B.CONTROLLERUSER AS CONTROLLERUSER,
		 B.CAMUSER,
		 B.USERNAME,
		 '' AS DIM3
FROM  XNYST A,
	 VXOLAPSECURITY B 
WHERE	 A.FRMEDLEM  = B.CONTROLLERUSER
 AND	A.FRGRPTYP  = 'U3'
 
 

/

/****************************************************************************
******* VDIM4
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VDIM4';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VDIM4 
AS 
SELECT DISTINCT
		 A.CUBEID AS TEMPLATE,
		 A.PARENT AS PARENT,
		 
(
SELECT DISTINCT RTRIM(NAME)
FROM  XOCUBEDIM4 C 
WHERE	 C.CHILD  = A.PARENT
 AND	C.CUBEID  = A.CUBEID

)
 AS PARENT_NAME,
		 LTRIM(RTRIM(A.CHILD)) AS DIM4,
		 RTRIM(A.NAME) AS DIM4_NAME,
		 B.NIV AS DIM_LEVEL
FROM  XOCUBEDIM4 A,
	 XKOD B 
WHERE	 A.CHILD  = B.KOD
 AND	B.TYP  = '4'

/

/****************************************************************************
******* VDIM4SECURITY
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VDIM4SECURITY';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VDIM4SECURITY 
AS 
SELECT DISTINCT
		 B.NTUSER AS OSUSER,
		 B.CONTROLLERUSER AS CONTROLLERUSER,
		 B.CAMUSER,
		 B.USERNAME,
		 A.TOMEDLEM AS DIM4
FROM  XNYST A,
	 VXOLAPSECURITY B 
WHERE	 A.FRMEDLEM  = B.CONTROLLERUSER
 AND	A.FRGRPTYP  = 'U4'
UNION
 SELECT DISTINCT
		 B.NTUSER AS OSUSER,
		 B.CONTROLLERUSER AS CONTROLLERUSER,
		 B.CAMUSER,
		 B.USERNAME,
		 LTRIM(RTRIM(A.KOD)) AS DIM4
FROM  XKOD A,
	 VXOLAPSECURITY B 
WHERE	 B.CONTROLLERUSER  NOT IN
	(
 	SELECT FRMEDLEM
	FROM  XNYST 
	WHERE	 FRGRPTYP  = 'U4'
	)
 AND	A.TYP  = '4'
UNION ALL
 SELECT DISTINCT
		 B.NTUSER AS OSUSER,
		 B.CONTROLLERUSER AS CONTROLLERUSER,
		 B.CAMUSER,
		 B.USERNAME,
		 '' AS DIM4
FROM  XNYST A,
	 VXOLAPSECURITY B 
WHERE	 A.FRMEDLEM  = B.CONTROLLERUSER
 AND	A.FRGRPTYP  = 'U4'
 
 

/

/****************************************************************************
******* VFACTS
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VFACTS';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VFACTS 
AS 
SELECT
		 CUBEID AS TEMPLATE,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 ACTUALITY AS ACTUALITY,
		 KTYPKONC AS GROUP_PERSPECTIVE,
		 BOL AS COMPANY,
		 VKOD AS CURRENCY,
		 KONTO AS ACCOUNT,
		 DIM1 AS DIM1,
		 DIM2 AS DIM2,
		 DIM3 AS DIM3,
		 DIM4 AS DIM4,
		 CLOSVER AS CLOSING_VERSION,
		 BTYP AS JOURNALTYPE,
		 CONTRIB AS CONTRIBUTION_VERSION,
		 ETYP AS AUTOMATIC_JOURNALTYPE,
		 MOTBOL AS COUNTER_COMPANY,
		 MOTDIM AS COUNTER_DIMENSION,
		 TRAVKD AS TRANSACTION_CURRENCY,
		 YTD AS YTD,
		 ROLLING AS PER,
		 TRYTD AS YTD_TRANSACTION_AMOUNT,
		 TRROLLING AS PER_TRANSACTION_AMOUNT
FROM  XOCUBEFACT 

/

/****************************************************************************
******* VFORMSECURITY
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VFORMSECURITY';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VFORMSECURITY 
AS 
SELECT DISTINCT
		 B.NTUSER AS OSUSER,
		 B.CONTROLLERUSER AS CONTROLLERUSER,
		 B.CAMUSER,
		 B.USERNAME,
		 LTRIM(RTRIM(A.TOMEDLEM)) AS FORM
FROM  XNYST A,
	 VXOLAPSECURITY B 
WHERE	 A.FRMEDLEM  = B.CONTROLLERUSER
 AND	A.FRGRPTYP  = 'UF'
UNION
 SELECT
		 B.NTUSER AS OSUSER,
		 B.CONTROLLERUSER AS CONTROLLERUSER,
		 B.CAMUSER,
		 B.USERNAME,
		 A.BNR AS FORM
FROM  XBR A,
	 VXOLAPSECURITY B 
WHERE	 B.CONTROLLERUSER  NOT IN
	(
 	SELECT FRMEDLEM
	FROM  XNYST 
	WHERE	 FRGRPTYP  = 'UF'
	)
UNION
 SELECT DISTINCT
		 B.NTUSER AS OSUSER,
		 B.CONTROLLERUSER AS CONTROLLERUSER,
		 B.CAMUSER,
		 B.USERNAME,
		 '' AS FORM
FROM  VXOLAPSECURITY B 
 
 

/

/****************************************************************************
******* VGROUPPERSPECTIVE
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VGROUPPERSPECTIVE';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VGROUPPERSPECTIVE 
AS 
SELECT A.CUBEID AS TEMPLATE, 
	   A.JOINCOL AS GROUP_ID, 
	   A.NAME AS GROUP_NAME, 
	   '' AS GROUP_PERSPECTIVE 
FROM XOCUBECOMP A INNER JOIN XOLAP B ON A.CUBEID = B.CUBEID 
INNER JOIN XKSTRUC C ON A.JOINCOL = C.BOL 
WHERE B.ISCOMPANY = '0' 
	  AND B.STRUCTVERSION BETWEEN C.FRPER AND C.TOPER 
	  AND C.BOLTYP = 'K' 
UNION 
SELECT A.CUBEID, 
	   A.JOINCOL, 
	   A.NAME, 
	   B.CONSTYPE 
FROM XOCUBECOMP A INNER JOIN XOLAP B ON A.CUBEID = B.CUBEID 
INNER JOIN XKSTRUC C ON A.JOINCOL = C.BOL 
WHERE B.ISCOMPANY = '0' 
	  AND B.STRUCTVERSION BETWEEN C.FRPER AND C.TOPER 
	  AND C.BOLTYP = 'K' 
UNION 
SELECT A.CUBEID, 
	   A.JOINCOL, 
	   A.NAME, 
	   B.CONSTYPE || A.JOINCOL 
FROM XOCUBECOMP A INNER JOIN XOLAP B ON A.CUBEID = B.CUBEID 
INNER JOIN XKSTRUC C ON A.JOINCOL = C.BOL 
WHERE B.ISCOMPANY = '0' 
	  AND B.STRUCTVERSION BETWEEN C.FRPER AND C.TOPER 
	  AND C.BOLTYP = 'K' 
 

/

/****************************************************************************
******* VTRANSACTIONCURRENCIES
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VTRANSACTIONCURRENCIES';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VTRANSACTIONCURRENCIES 
AS 
SELECT DISTINCT
		 CUBEID AS TEMPLATE,
		 VKOD AS CURRENCY,
		 SORTORD AS SORTORDER
FROM  XOCUBECURR 
UNION
 SELECT
		 CUBEID AS TEMPLATE,
		 '' AS CURRENCY,
		 0 AS SORTORDER
FROM  XOCUBECURR 
 

/

/****************************************************************************
******* VREL_PER
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VREL_PER';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VREL_PER 
AS 
SELECT
		 CUBEID AS TEMPLATE,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 '+0' AS CODE,
		 CAST(PERIOD AS char (6)) AS RELATIVE_PERIOD
FROM  XOCUBEPERIOD 
UNION ALL
 SELECT
		 CUBEID,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 '-1' AS CODE,
		 
			CASE
				 WHEN SUBSTR(PERIOD, LENGTH(PERIOD) - 2 +1, 2)  < '02' THEN CAST(PERIOD - 89 AS char (6))
				 ELSE CAST(PERIOD - 1 AS char (6))
			 END
FROM  XOCUBEPERIOD 
UNION ALL
 SELECT
		 CUBEID,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 '-2' AS CODE,
		 
			CASE
				 WHEN SUBSTR(PERIOD, LENGTH(PERIOD) - 2 +1, 2)  < '03' THEN CAST(PERIOD - 90 AS char (6))
				 ELSE CAST(PERIOD - 2 AS char (6))
			 END
FROM  XOCUBEPERIOD 
UNION ALL
 SELECT
		 CUBEID,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 '-3' AS CODE,
		 
			CASE
				 WHEN SUBSTR(PERIOD, LENGTH(PERIOD) - 2 +1, 2)  < '04' THEN CAST(PERIOD - 91 AS char (6))
				 ELSE CAST(PERIOD - 3 AS char (6))
			 END
FROM  XOCUBEPERIOD 
UNION ALL
 SELECT
		 CUBEID,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 '-4' AS CODE,
		 
			CASE
				 WHEN SUBSTR(PERIOD, LENGTH(PERIOD) - 2 +1, 2)  < '05' THEN CAST(PERIOD - 92 AS char (6))
				 ELSE CAST(PERIOD - 4 AS char (6))
			 END
FROM  XOCUBEPERIOD 
UNION ALL
 SELECT
		 CUBEID,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 '-5' AS CODE,
		 
			CASE
				 WHEN SUBSTR(PERIOD, LENGTH(PERIOD) - 2 +1, 2)  < '06' THEN CAST(PERIOD - 93 AS char (6))
				 ELSE CAST(PERIOD - 5 AS char (6))
			 END
FROM  XOCUBEPERIOD 
UNION ALL
 SELECT
		 CUBEID,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 '-6' AS CODE,
		 
			CASE
				 WHEN SUBSTR(PERIOD, LENGTH(PERIOD) - 2 +1, 2)  < '07' THEN CAST(PERIOD - 94 AS char (6))
				 ELSE CAST(PERIOD - 6 AS char (6))
			 END
FROM  XOCUBEPERIOD 
UNION ALL
 SELECT
		 CUBEID,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 '-7' AS CODE,
		 
			CASE
				 WHEN SUBSTR(PERIOD, LENGTH(PERIOD) - 2 +1, 2)  < '08' THEN CAST(PERIOD - 95 AS char (6))
				 ELSE CAST(PERIOD - 7 AS char (6))
			 END
FROM  XOCUBEPERIOD 
UNION ALL
 SELECT
		 CUBEID,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 '-8' AS CODE,
		 
			CASE
				 WHEN SUBSTR(PERIOD, LENGTH(PERIOD) - 2 +1, 2)  < '09' THEN CAST(PERIOD - 96 AS char (6))
				 ELSE CAST(PERIOD - 8 AS char (6))
			 END
FROM  XOCUBEPERIOD 
UNION ALL
 SELECT
		 CUBEID,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 '-9' AS CODE,
		 
			CASE
				 WHEN SUBSTR(PERIOD, LENGTH(PERIOD) - 2 +1, 2)  < '10' THEN CAST(PERIOD - 97 AS char (6))
				 ELSE CAST(PERIOD - 9 AS char (6))
			 END
FROM  XOCUBEPERIOD 
UNION ALL
 SELECT
		 CUBEID,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 '-10' AS CODE,
		 
			CASE
				 WHEN SUBSTR(PERIOD, LENGTH(PERIOD) - 2 +1, 2)  < '11' THEN CAST(PERIOD - 98 AS char (6))
				 ELSE CAST(PERIOD - 10 AS char (6))
			 END
FROM  XOCUBEPERIOD 
UNION ALL
 SELECT
		 CUBEID,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 '-11' AS CODE,
		 
			CASE
				 WHEN SUBSTR(PERIOD, LENGTH(PERIOD) - 2 +1, 2)  < '12' THEN CAST(PERIOD - 99 AS char (6))
				 ELSE CAST(PERIOD - 11 AS char (6))
			 END
FROM  XOCUBEPERIOD 
UNION ALL
 SELECT
		 CUBEID,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 '-12' AS CODE,
		 CAST(PERIOD - 100 AS char (6))
FROM  XOCUBEPERIOD 
UNION ALL
 SELECT
		 CUBEID,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 '+1' AS CODE,
		 
			CASE
				 WHEN SUBSTR(PERIOD, LENGTH(PERIOD) - 2 +1, 2)  > '11' THEN CAST(PERIOD + 89 AS char (6))
				 ELSE CAST(PERIOD + 1 AS char (6))
			 END
FROM  XOCUBEPERIOD 
UNION ALL
 SELECT
		 CUBEID,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 '+2' AS CODE,
		 
			CASE
				 WHEN SUBSTR(PERIOD, LENGTH(PERIOD) - 2 +1, 2)  > '10' THEN CAST(PERIOD + 90 AS char (6))
				 ELSE CAST(PERIOD + 2 AS char (6))
			 END
FROM  XOCUBEPERIOD 
UNION ALL
 SELECT
		 CUBEID,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 '+3' AS CODE,
		 
			CASE
				 WHEN SUBSTR(PERIOD, LENGTH(PERIOD) - 2 +1, 2)  > '09' THEN CAST(PERIOD + 91 AS char (6))
				 ELSE CAST(PERIOD + 3 AS char (6))
			 END
FROM  XOCUBEPERIOD 
UNION ALL
 SELECT
		 CUBEID,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 '+4' AS CODE,
		 
			CASE
				 WHEN SUBSTR(PERIOD, LENGTH(PERIOD) - 2 +1, 2)  > '08' THEN CAST(PERIOD + 92 AS char (6))
				 ELSE CAST(PERIOD + 4 AS char (6))
			 END
FROM  XOCUBEPERIOD 
UNION ALL
 SELECT
		 CUBEID,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 '+5' AS CODE,
		 
			CASE
				 WHEN SUBSTR(PERIOD, LENGTH(PERIOD) - 2 +1, 2)  > '07' THEN CAST(PERIOD + 93 AS char (6))
				 ELSE CAST(PERIOD + 5 AS char (6))
			 END
FROM  XOCUBEPERIOD 
UNION ALL
 SELECT
		 CUBEID,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 '+6' AS CODE,
		 
			CASE
				 WHEN SUBSTR(PERIOD, LENGTH(PERIOD) - 2 +1, 2)  > '06' THEN CAST(PERIOD + 94 AS char (6))
				 ELSE CAST(PERIOD + 6 AS char (6))
			 END
FROM  XOCUBEPERIOD 
UNION ALL
 SELECT
		 CUBEID,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 '+7' AS CODE,
		 
			CASE
				 WHEN SUBSTR(PERIOD, LENGTH(PERIOD) - 2 +1, 2)  > '05' THEN CAST(PERIOD + 95 AS char (6))
				 ELSE CAST(PERIOD + 7 AS char (6))
			 END
FROM  XOCUBEPERIOD 
UNION ALL
 SELECT
		 CUBEID,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 '+8' AS CODE,
		 
			CASE
				 WHEN SUBSTR(PERIOD, LENGTH(PERIOD) - 2 +1, 2)  > '04' THEN CAST(PERIOD + 96 AS char (6))
				 ELSE CAST(PERIOD + 8 AS char (6))
			 END
FROM  XOCUBEPERIOD 
UNION ALL
 SELECT
		 CUBEID,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 '+9' AS CODE,
		 
			CASE
				 WHEN SUBSTR(PERIOD, LENGTH(PERIOD) - 2 +1, 2)  > '03' THEN CAST(PERIOD + 97 AS char (6))
				 ELSE CAST(PERIOD + 9 AS char (6))
			 END
FROM  XOCUBEPERIOD 
UNION ALL
 SELECT
		 CUBEID,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 '+10' AS CODE,
		 
			CASE
				 WHEN SUBSTR(PERIOD, LENGTH(PERIOD) - 2 +1, 2)  > '02' THEN CAST(PERIOD + 98 AS char (6))
				 ELSE CAST(PERIOD + 10 AS char (6))
			 END
FROM  XOCUBEPERIOD 
UNION ALL
 SELECT
		 CUBEID,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 '+11' AS CODE,
		 
			CASE
				 WHEN SUBSTR(PERIOD, LENGTH(PERIOD) - 2 +1, 2)  > '01' THEN CAST(PERIOD + 99 AS char (6))
				 ELSE CAST(PERIOD + 11 AS char (6))
			 END
FROM  XOCUBEPERIOD 
UNION ALL
 SELECT
		 CUBEID,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 '+12' AS CODE,
		 CAST(PERIOD + 100 AS char (6))
FROM  XOCUBEPERIOD 
UNION ALL
 SELECT
		 CUBEID,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 'P012' AS CODE,
		 SUBSTR(PERIOD, 0, 4) || '12'
FROM  XOCUBEPERIOD 
UNION ALL
 SELECT
		 CUBEID,
		 CAST(PERIOD AS char (6)) AS PERIOD,
		 'N112' AS CODE,
		 CAST(SUBSTR(PERIOD, 0, 4) - 1 AS CHAR (4)) || '12'
FROM  XOCUBEPERIOD 
 
 
/

/****************************************************************************
******* VPERIOD_CAPTION
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VPERIOD_CAPTION';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VPERIOD_CAPTION 
AS 
SELECT
		 A.ID AS PERIOD,
		 RTRIM(A.IDNAMN) AS NAME,
		 RTRIM(C.IDNAMN) AS SHORT_NAME
FROM  XIDT A,
	 XKONFIG B,
	 XIDT C 
WHERE	 A.LOCALEID  = B.KONFTXT
 AND	(A.ID  = C.ID)
 AND	(A.TYP  = 'M1'
 AND	A.LOCALEID  = B.KONFTXT
 AND	B.TYP1  = 'C'
 AND	B.TYP2  = 'GLOCALE'
 AND	C.TYP  = 'M2'
 AND	C.LOCALEID  = B.KONFTXT)

/

/****************************************************************************
******* VTEMPLATES
****************************************************************************/
BEGIN 
EXECUTE IMMEDIATE 'DROP VIEW VTEMPLATES';
EXCEPTION WHEN OTHERS THEN NULL;
END;
/

CREATE VIEW VTEMPLATES 
AS 
SELECT DISTINCT
		 A.CUBEID AS TEMPLATE,
		 RTRIM(B.CUBENAME) AS CUBENAME,
		 
			CASE
				 WHEN A.CUBETYPE  = 0 THEN 'Default'
				 ELSE 'Statutory'
			 END AS CUBETYPE,
		 
			CASE
				 WHEN A.TARGET  = 0 THEN 'False'
				 ELSE 'True'
			 END AS TARGET,
		 
			CASE
				 WHEN A.ISINCREMENTAL  = 0 THEN 'Full'
				 ELSE 'Incremental'
			 END EXPORT_OPTION,
		 
			CASE
				 WHEN A.ISACCOUNT  = 0 THEN 'Form'
				 ELSE 'Account'
			 END AS ACCOUNT,
		 
			CASE
				 WHEN A.ISCOMPANY  = 0 THEN 'Group'
				 ELSE 'Company'
			 END AS COMPANY,
		 
			CASE
				 WHEN A.ISCOMPANY  = 0 THEN CAST(A.STRUCTVERSION AS char (6))
				 ELSE 'N/A'
			 END AS STRUCTVERSION,
		 
			CASE
				 WHEN A.ISCOMPANY  = 0 THEN 
					CASE
						 WHEN A.DOSUBGROUPS  = 0 THEN 'False'
						 ELSE 'True'
					 END
				 ELSE 'N/A'
			 END AS INCLUDE_SUBGROUPS,
		 
			CASE
				 WHEN A.ISCOMPANY  = 0 THEN A.CONSTYPE
				 ELSE 'N/A'
			 END AS CONSTYPE,
		 
			CASE
				 WHEN A.CLOSVERDETAILS  = 0 THEN 'False'
				 ELSE 'True'
			 END AS CLOSVERDETAILS,
		 
			CASE
				 WHEN A.CUBETYPE  = 0 THEN 'N/A'
				 ELSE 
					CASE
						 WHEN A.CONTRIBDETAILS  = 0 THEN 'False'
						 ELSE 'True'
					 END
			 END AS CONTRIBDETAILS,
		 A.DIM1LEVEL,
		 A.DIM2LEVEL,
		 A.DIM3LEVEL,
		 A.DIM4LEVEL,
		 A.STATUSDATE AS CREATED_DATE,
		 B.LOCALEID
FROM  XOLAP A,
	 XOLAPT B,
	 XKONFIG C 
WHERE	 A.CUBEID  = B.CUBEID
 AND	C.TYP1  = 'C'
 AND	C.TYP2  = 'GLOCALE'
 AND	B.LOCALEID  = C.KONFTXT

/

/****************************************************************************
******* globalPkg
****************************************************************************/
CREATE OR REPLACE PACKAGE globalPkg AUTHID CURRENT_USER AS
/* The following are T/SQL specific global variables. */
  identity  INTEGER;
  trancount INTEGER;
  TYPE RCT1 IS REF CURSOR;/*new weak cursor definition*/
  PROCEDURE incTrancount;
  PROCEDURE decTrancount;
END globalPkg;

/

/****************************************************************************
******* PGROUPSTATUS
****************************************************************************/
CREATE OR REPLACE PROCEDURE PGROUPSTATUS
(
	Constype                   IN      	VARCHAR2 DEFAULT NULL,
	GROUP_                     IN      	VARCHAR2 DEFAULT NULL,
	Period                     IN  OUT 	VARCHAR2,
	Actuality                  IN  OUT 	VARCHAR2,
	Submission                 IN  OUT 	VARCHAR2,
	RCT1                        IN  OUT 	GLOBALPKG.RCT1
)
AS
BEGIN 
	
	OPEN RCT1 FOR 
	SELECT
			 PGROUPSTATUS.Period as Period,
			 PGROUPSTATUS.Actuality as Actuality,
			 a.konctyp as Consolidation_Type,
			 a.koncern,
			 a.bol,
			 a.bolnamn,
			 a.boltyp,
			 a.niva,
			 PGROUPSTATUS.Submission as Submission,
			 NVL(b.status, '0') as status,
			 a.vkod,
			 
				case
					 when NVL(b.status, '0')  = '1' then 1
					 else 0
				 end as "1",
			 
				case
					 when NVL(b.status, '0')  = '2' then 1
					 else 0
				 end as "2",
			 
				case
					 when NVL(b.status, '0')  = '3' then 1
					 else 0
				 end as "3",
			 
				case
					 when NVL(b.status, '0')  = '0' then 1
					 else 0
				 end as "0"
	FROM (	SELECT
				 a.konctyp,
				 a.koncern,
				 a.bol,
				 c.bolnamn,
				 a.niva,
				 a.boltyp,
				 b.vkodlc as vkod
		FROM  xkstruc a,
			 xbo b,
			 xbot c,
			 xkonfig d 
		WHERE	 a.konctyp  = PGROUPSTATUS.Constype
		 AND	a.koncern  = PGROUPSTATUS.GROUP_
		 AND	a.frper  <= PGROUPSTATUS.Period
		 AND	a.toper  >= PGROUPSTATUS.Period
		 AND	a.bol  = b.bol
		 AND	a.bol  = c.bol
		 AND	c.localeid  = d.konftxt
		 AND	d.typ1  = 'C'
		 AND	d.typ2  = 'GLOCALE'
	) a,
		(	SELECT *
		FROM  xrepstat b 
		WHERE	 SUBSTR(b.perakt, 0, 4)  = SUBSTR(PGROUPSTATUS.Period, 3, 4)
		 AND	SUBSTR(B.perakt, LENGTH(B.perakt) - 2 +1, 2)  = PGROUPSTATUS.Actuality
		 AND	b.bnr  = RPAD(' ', 4)
	) b 
	WHERE	 a.bol  = b.bol (+)
	 AND	a.vkod  = b.vkod (+)
	 AND	b.subm (+) = PGROUPSTATUS.Submission;
END;
/

/****************************************************************************
******* PREPORTINGSTATUS
****************************************************************************/
CREATE OR REPLACE PROCEDURE PREPORTINGSTATUS
(
	Company                    IN  OUT 	VARCHAR2,
	Period                     IN      	VARCHAR2 DEFAULT NULL,
	Actuality                  IN  OUT 	VARCHAR2,
	Submission                 IN      	VARCHAR2 DEFAULT NULL,
	Currency                   IN      	VARCHAR2 DEFAULT NULL,
	RCT1                        IN  OUT 	GLOBALPKG.RCT1
)
AS
BEGIN 
	
	OPEN RCT1 FOR 
	SELECT DISTINCT
			 SUBSTR(PREPORTINGSTATUS.Period, 3, 4) AS Period,
			 PREPORTINGSTATUS.Actuality AS Actuality,
			 PREPORTINGSTATUS.Company as Company,
			 a.bnr AS Form,
			 a.bnrnamn as "Form Name",
			 NVL(b.vkod, '') AS vkod,
			 NVL(b.status, '0') AS status,
			 B.CRDATE AS Created,
			 B.CRUSER AS "CR_USER",
			 B.CRSYS AS CR_SYSTEM,
			 B.CHDATE AS UPDATED,
			 B.CHUSER AS "USER",
			 B.CHSYS AS CH_SYSTEM
	FROM (	SELECT DISTINCT
				 a.bnr,
				 b.bnrnamn
		FROM  xbr a,
			 xbrt b,
			 xbset c,
			 xkonfig d,
			 xsubm e 
		WHERE	 a.bnr  = b.bnr
		 AND	b.localeid  = d.konftxt
		 AND	d.typ1  = 'C'
		 AND	d.typ2  = 'GLOCALE'
		 AND	a.bnr  = c.bnr
		 AND	e.subm  = PREPORTINGSTATUS.Submission
		 AND	e.bnrset  = c.bnrset
		 AND	SUBSTR(e.perakt, 0, 4)  = SUBSTR(PREPORTINGSTATUS.Period, 3, 4)
		 AND	SUBSTR(e.perakt, LENGTH(e.perakt) - 2 +1, 2)  = PREPORTINGSTATUS.Actuality
		 AND	c.bnrset  <> ''
	) a,
		(	SELECT *
		FROM  xrepstat b 
		WHERE	 B.BNR  <> ''
		 AND	SUBSTR(b.perakt, 0, 4)  = SUBSTR(PREPORTINGSTATUS.Period, 3, 4)
		 AND	SUBSTR(B.perakt, LENGTH(B.perakt) - 2 +1, 2)  = PREPORTINGSTATUS.Actuality
	) b 
	WHERE	 a.bnr  = b.bnr (+)
	 AND	b.subm (+) = PREPORTINGSTATUS.Submission
	 AND	b.bol (+) = PREPORTINGSTATUS.Company
	 AND	b.vkod (+) = PREPORTINGSTATUS.Currency;
END;
/